<template>
	<el-dialog v-model="dialogVisible" @close="resetForm(ruleFormRef)" :fullscreen="full" :title="titles" width="30%" draggable>
		<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
		<el-form :model="form" ref="ruleFormRef" :rules="rules" :disabled="disabled" label-width="120px">
			<el-row>
				<el-col :span="20">
					<el-form-item label="名称" size="default" prop="typeName">
						<el-input v-model="form.typeName" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="20">
					<el-form-item label="描述" size="default" prop="memo">
						<el-input v-model="form.memo" type="textarea" />
					</el-form-item>
				</el-col>
			</el-row>
		</el-form>
		<template #footer>
			<span class="dialog-footer">
				<el-button @click="resetForm(ruleFormRef)" size="default">关闭</el-button>
				<el-button type="primary" v-if="disabled == false" @click="submitForm(ruleFormRef)" size="default">确定</el-button>
			</span>
		</template>
	</el-dialog>
</template>
<script lang="ts">
import { defineComponent, ref, reactive } from 'vue';
import { timeDate } from '/@/assets/index.ts';
import type { FormInstance, FormRules } from 'element-plus';
import { Search, FullScreen } from '@element-plus/icons-vue';
import { ElMessageBox, ElMessage, ElButton, ElInput, TabsPaneContext } from 'element-plus';
import { goalManagementApi } from '/@/api/goalManagement';
export default defineComponent({
	components: {},
	setup(props, { emit }) {
		const ruleFormRef = ref<FormInstance>();
		const dialogVisible = ref<boolean>(false);
		const form = ref({
			typeName: '',
			memo: '',
		});
		const targetType = ref();
		const disabled = ref(false);
		const titles = ref();
		const titleT=ref()
		const openDailog = (title: string, type: any, id: number) => {
			dialogVisible.value = true;
			titles.value = `${title}目标分解`;
			titleT.value=title
			targetType.value = type;
			disabled.value = title == '查看' ? true : false;
			if (title == '查看' || title == '修改') {
				goalManagementApi()
					.gettargetClassDetail(id)
					.then((res) => {
						if (res.data.code == 200) {
							form.value = res.data.data;
						} else {
							ElMessage.error(res.data.msg);
						}
					});
			}
		};
		const rules = reactive<FormRules>({
			typeName: [
				{
					required: true,
					message: '名称不能为空',
					trigger: 'blur',
				},
			],
			memo: [
				{
					required: true,
					message: '描述不能为空',
					trigger: 'blur',
				},
			],
		});
		const submitForm = async (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			await formEl.validate((valid, fields) => {
				if (valid) {
					if(titleT.value=='新建'){
						delete form.value.id
					}
					dialogVisible.value = false;
					goalManagementApi()
						.gettargetClassAdd(form.value)
						.then((res) => {
							if (res.data.code == 200) {
								ElMessage({
									message: res.data.msg,
									type: 'success',
								});
                                emit('onAdd');
							} else {
								ElMessage.error(res.data.msg);
							}
						});
				} else {
					console.log('error submit!', fields);
				}
			});
		};
		const resetForm = (formEl: FormInstance | undefined) => {
			if (!formEl) return;
			formEl.resetFields();
			dialogVisible.value = false;
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		return {
			timeDate,
			ruleFormRef,
			titleT,
			rules,
			submitForm,
			resetForm,
			form,
			dialogVisible,
			openDailog,
			Search,
			full,
			toggleFullscreen,
			FullScreen,
			targetType,
			disabled,
			titles,
		};
	},
});
</script>
<style scoped>
.el-row {
	padding: 0 0 20px 0;
}
</style>
